# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/webhook.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/webhook.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/iam/identityaccount/v1/webhook.proto\x12!ai.stigmer.iam.identityaccount.v1\"\xde\x01\n\x0c\x41uth0Webhook\x12\x12\n\x04\x64\x61te\x18\x01 \x01(\tR\x04\x64\x61te\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tclient_id\x18\x04 \x01(\tR\x08\x63lientId\x12\x1f\n\x0b\x63lient_name\x18\x05 \x01(\tR\nclientName\x12\x0e\n\x02ip\x18\x06 \x01(\tR\x02ip\x12\x1d\n\nuser_agent\x18\x07 \x01(\tR\tuserAgent\x12\x17\n\x07user_id\x18\x08 \x01(\tR\x06userIdB\xde\x01\n%com.ai.stigmer.iam.identityaccount.v1B\x0cWebhookProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.webhook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\014WebhookProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_AUTH0WEBHOOK']._serialized_start=87
  _globals['_AUTH0WEBHOOK']._serialized_end=309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.skill.v1 import status_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ai/stigmer/agentic/skill/v1/io.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\x1a(ai/stigmer/agentic/skill/v1/status.proto\x1a\x1b\x62uf/validate/validate.proto\"\'\n\x07SkillId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\xd8\x01\n\x10PushSkillRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12\"\n\x08\x61rtifact\x18\x02 \x01(\x0c\x42\x06\xbaH\x03\xc8\x01\x01R\x08\x61rtifact\x12-\n\x03tag\x18\x03 \x01(\tB\x1b\xbaH\x18r\x16\x32\x14^$|^[a-zA-Z0-9._-]+$R\x03tag\x12Q\n\x0egit_provenance\x18\x04 \x01(\x0b\x32*.ai.stigmer.agentic.skill.v1.GitProvenanceR\rgitProvenanceJ\x04\x08\x05\x10\x06\"\xc6\x01\n%PushSkillFromExecutionArtifactRequest\x12\x18\n\x03org\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x03org\x12*\n\x0c\x65xecution_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x65xecutionId\x12(\n\x0bstorage_key\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\x12-\n\x03tag\x18\x04 \x01(\tB\x1b\xbaH\x18r\x16\x32\x14^$|^[a-zA-Z0-9._-]+$R\x03tag\"N\n\x12GetArtifactRequest\x12\x38\n\x14\x61rtifact_storage_key\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x12\x61rtifactStorageKey\"1\n\x13GetArtifactResponse\x12\x1a\n\x08\x61rtifact\x18\x01 \x01(\x0cR\x08\x61rtifactB\xbb\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\007IoProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLID'].fields_by_name['value']._loaded_options = None
  _globals['_SKILLID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_PUSHSKILLREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLREQUEST'].fields_by_name['artifact']._loaded_options = None
  _globals['_PUSHSKILLREQUEST'].fields_by_name['artifact']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLREQUEST'].fields_by_name['tag']._loaded_options = None
  _globals['_PUSHSKILLREQUEST'].fields_by_name['tag']._serialized_options = b'\272H\030r\0262\024^$|^[a-zA-Z0-9._-]+$'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['org']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['execution_id']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['execution_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['storage_key']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['tag']._loaded_options = None
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST'].fields_by_name['tag']._serialized_options = b'\272H\030r\0262\024^$|^[a-zA-Z0-9._-]+$'
  _globals['_GETARTIFACTREQUEST'].fields_by_name['artifact_storage_key']._loaded_options = None
  _globals['_GETARTIFACTREQUEST'].fields_by_name['artifact_storage_key']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SKILLID']._serialized_start=140
  _globals['_SKILLID']._serialized_end=179
  _globals['_PUSHSKILLREQUEST']._serialized_start=182
  _globals['_PUSHSKILLREQUEST']._serialized_end=398
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST']._serialized_start=401
  _globals['_PUSHSKILLFROMEXECUTIONARTIFACTREQUEST']._serialized_end=599
  _globals['_GETARTIFACTREQUEST']._serialized_start=601
  _globals['_GETARTIFACTREQUEST']._serialized_end=679
  _globals['_GETARTIFACTRESPONSE']._serialized_start=681
  _globals['_GETARTIFACTRESPONSE']._serialized_end=730
# @@protoc_insertion_point(module_scope)



from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from ai.stigmer.commons.apiresource import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReconciliationSummary(_message.Message):
    __slots__ = ("created", "updated", "deleted")
    CREATED_FIELD_NUMBER: _ClassVar[int]
    UPDATED_FIELD_NUMBER: _ClassVar[int]
    DELETED_FIELD_NUMBER: _ClassVar[int]
    created: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    updated: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    deleted: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    def __init__(self, created: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ..., updated: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ..., deleted: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ...) -> None: ...

class ProjectStatus(_message.Message):
    __slots__ = ("last_reconciliation", "audit")
    LAST_RECONCILIATION_FIELD_NUMBER: _ClassVar[int]
    AUDIT_FIELD_NUMBER: _ClassVar[int]
    last_reconciliation: ReconciliationSummary
    audit: _status_pb2.ApiResourceAudit
    def __init__(self, last_reconciliation: _Optional[_Union[ReconciliationSummary, _Mapping]] = ..., audit: _Optional[_Union[_status_pb2.ApiResourceAudit, _Mapping]] = ...) -> None: ...



from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as _api_resource_kind_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
API_RESOURCE_KIND_FIELD_NUMBER: _ClassVar[int]
api_resource_kind: _descriptor.FieldDescriptor



from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from ai.stigmer.tenancy.organization.v1 import enum_pb2 as _enum_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrganizationSpec(_message.Message):
    __slots__ = ("description", "logo_url", "management_mode", "identity_provider_ref", "external_org_id", "is_personal")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    MANAGEMENT_MODE_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_REF_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ORG_ID_FIELD_NUMBER: _ClassVar[int]
    IS_PERSONAL_FIELD_NUMBER: _ClassVar[int]
    description: str
    logo_url: str
    management_mode: _enum_pb2.ManagementMode
    identity_provider_ref: _io_pb2.ApiResourceReference
    external_org_id: str
    is_personal: bool
    def __init__(self, description: _Optional[str] = ..., logo_url: _Optional[str] = ..., management_mode: _Optional[_Union[_enum_pb2.ManagementMode, str]] = ..., identity_provider_ref: _Optional[_Union[_io_pb2.ApiResourceReference, _Mapping]] = ..., external_org_id: _Optional[str] = ..., is_personal: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.mcpserver.v1 import status_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/agentic/mcpserver/v1/io.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a,ai/stigmer/agentic/mcpserver/v1/status.proto\x1a\x1b\x62uf/validate/validate.proto\"+\n\x0bMcpServerId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\xc9\x01\n!UpdateDiscoveredCapabilitiesInput\x12*\n\rmcp_server_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0bmcpServerId\x12x\n\x17\x64iscovered_capabilities\x18\x02 \x01(\x0b\x32\x37.ai.stigmer.agentic.mcpserver.v1.DiscoveredCapabilitiesB\x06\xbaH\x03\xc8\x01\x01R\x16\x64iscoveredCapabilitiesB\xcf\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\007IoProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_MCPSERVERID'].fields_by_name['value']._loaded_options = None
  _globals['_MCPSERVERID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEDISCOVEREDCAPABILITIESINPUT'].fields_by_name['mcp_server_id']._loaded_options = None
  _globals['_UPDATEDISCOVEREDCAPABILITIESINPUT'].fields_by_name['mcp_server_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATEDISCOVEREDCAPABILITIESINPUT'].fields_by_name['discovered_capabilities']._loaded_options = None
  _globals['_UPDATEDISCOVEREDCAPABILITIESINPUT'].fields_by_name['discovered_capabilities']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MCPSERVERID']._serialized_start=152
  _globals['_MCPSERVERID']._serialized_end=195
  _globals['_UPDATEDISCOVEREDCAPABILITIESINPUT']._serialized_start=198
  _globals['_UPDATEDISCOVEREDCAPABILITIESINPUT']._serialized_end=399
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/mcpserver/v1/status.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd7\x02\n\x0fMcpServerStatus\x12[\n\x10validation_state\x18\x01 \x01(\x0e\x32\x30.ai.stigmer.agentic.mcpserver.v1.ValidationStateR\x0fvalidationState\x12-\n\x12validation_message\x18\x02 \x01(\tR\x11validationMessage\x12p\n\x17\x64iscovered_capabilities\x18\x03 \x01(\x0b\x32\x37.ai.stigmer.agentic.mcpserver.v1.DiscoveredCapabilitiesR\x16\x64iscoveredCapabilities\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\"\xec\x02\n\x16\x44iscoveredCapabilities\x12\x45\n\x05tools\x18\x01 \x03(\x0b\x32/.ai.stigmer.agentic.mcpserver.v1.DiscoveredToolR\x05tools\x12j\n\x12resource_templates\x18\x02 \x03(\x0b\x32;.ai.stigmer.agentic.mcpserver.v1.DiscoveredResourceTemplateR\x11resourceTemplates\x12H\n\x12last_discovered_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10lastDiscoveredAt\x12U\n\rdiscovered_by\x18\x04 \x01(\x0e\x32\x30.ai.stigmer.agentic.mcpserver.v1.DiscoverySourceR\x0c\x64iscoveredBy\"\x82\x01\n\x0e\x44iscoveredTool\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12:\n\x0cinput_schema\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0binputSchema\"\x92\x01\n\x1a\x44iscoveredResourceTemplate\x12!\n\x0curi_template\x18\x01 \x01(\tR\x0buriTemplate\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1b\n\tmime_type\x18\x04 \x01(\tR\x08mimeType*K\n\x0fValidationState\x12 \n\x1cvalidation_state_unspecified\x10\x00\x12\t\n\x05valid\x10\x01\x12\x0b\n\x07invalid\x10\x02*\\\n\x0f\x44iscoverySource\x12 \n\x1c\x64iscovery_source_unspecified\x10\x00\x12\x0c\n\x08seedpack\x10\x01\x12\x07\n\x03\x63li\x10\x02\x12\x10\n\x0c\x61gent_runner\x10\x03\x42\xd3\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\x0bStatusProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\013StatusProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_VALIDATIONSTATE']._serialized_start=1184
  _globals['_VALIDATIONSTATE']._serialized_end=1259
  _globals['_DISCOVERYSOURCE']._serialized_start=1261
  _globals['_DISCOVERYSOURCE']._serialized_end=1353
  _globals['_MCPSERVERSTATUS']._serialized_start=190
  _globals['_MCPSERVERSTATUS']._serialized_end=533
  _globals['_DISCOVEREDCAPABILITIES']._serialized_start=536
  _globals['_DISCOVEREDCAPABILITIES']._serialized_end=900
  _globals['_DISCOVEREDTOOL']._serialized_start=903
  _globals['_DISCOVEREDTOOL']._serialized_end=1033
  _globals['_DISCOVEREDRESOURCETEMPLATE']._serialized_start=1036
  _globals['_DISCOVEREDRESOURCETEMPLATE']._serialized_end=1182
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/artifact.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/artifact.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ai/stigmer/agentic/agentexecution/v1/artifact.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\x1a\x1b\x62uf/validate/validate.proto\"\xe0\x02\n\x11\x45xecutionArtifact\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12!\n\x0csandbox_path\x18\x02 \x01(\tR\x0bsandboxPath\x12Y\n\x04kind\x18\x03 \x01(\x0e\x32;.ai.stigmer.agentic.agentexecution.v1.ExecutionArtifactKindB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x04kind\x12\x1d\n\nsize_bytes\x18\x04 \x01(\x03R\tsizeBytes\x12\x1f\n\x0bstorage_key\x18\x05 \x01(\tR\nstorageKey\x12!\n\x0c\x64ownload_url\x18\x06 \x01(\tR\x0b\x64ownloadUrl\x12\x1d\n\ncreated_at\x18\x07 \x01(\tR\tcreatedAt\x12\x1d\n\nexpires_at\x18\x08 \x01(\tR\texpiresAt\x12\x18\n\x07\x65ntries\x18\t \x03(\tR\x07\x65ntriesB\xee\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\rArtifactProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.artifact_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\rArtifactProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_EXECUTIONARTIFACT'].fields_by_name['kind']._loaded_options = None
  _globals['_EXECUTIONARTIFACT'].fields_by_name['kind']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_EXECUTIONARTIFACT']._serialized_start=172
  _globals['_EXECUTIONARTIFACT']._serialized_end=524
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflow.v1.serverless import validation_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_serverless_dot_validation__pb2
from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/agentic/workflow/v1/status.proto\x12\x1e\x61i.stigmer.agentic.workflow.v1\x1a:ai/stigmer/agentic/workflow/v1/serverless/validation.proto\x1a+ai/stigmer/commons/apiresource/status.proto\"\x98\x02\n\x0eWorkflowStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12.\n\x13\x64\x65\x66\x61ult_instance_id\x18\x01 \x01(\tR\x11\x64\x65\x66\x61ultInstanceId\x12\x8d\x01\n\x1eserverless_workflow_validation\x18\x02 \x01(\x0b\x32G.ai.stigmer.agentic.workflow.v1.serverless.ServerlessWorkflowValidationR\x1cserverlessWorkflowValidationB\xce\x01\n\"com.ai.stigmer.agentic.workflow.v1B\x0bStatusProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\x1e\x41i.Stigmer.Agentic.Workflow.V1\xca\x02\x1e\x41i\\Stigmer\\Agentic\\Workflow\\V1\xe2\x02*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\xea\x02\"Ai::Stigmer::Agentic::Workflow::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.agentic.workflow.v1B\013StatusProtoP\001\242\002\004ASAW\252\002\036Ai.Stigmer.Agentic.Workflow.V1\312\002\036Ai\\Stigmer\\Agentic\\Workflow\\V1\342\002*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\352\002\"Ai::Stigmer::Agentic::Workflow::V1'
  _globals['_WORKFLOWSTATUS']._serialized_start=185
  _globals['_WORKFLOWSTATUS']._serialized_end=465
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.agentexecution.v1 import approval_pb2 as _approval_pb2
from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from ai.stigmer.agentic.agentexecution.v1 import message_pb2 as _message_pb2
from ai.stigmer.agentic.agentexecution.v1 import usage_pb2 as _usage_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubAgentExecution(_message.Message):
    __slots__ = ("id", "name", "input", "output", "status", "started_at", "completed_at", "error", "metadata", "tool_calls", "messages", "usage", "subject", "pending_approvals")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TOOL_CALLS_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    PENDING_APPROVALS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    input: str
    output: str
    status: _enum_pb2.SubAgentStatus
    started_at: str
    completed_at: str
    error: str
    metadata: _struct_pb2.Struct
    tool_calls: _containers.RepeatedCompositeFieldContainer[_message_pb2.ToolCall]
    messages: _containers.RepeatedCompositeFieldContainer[_message_pb2.AgentMessage]
    usage: _usage_pb2.UsageMetrics
    subject: str
    pending_approvals: _containers.RepeatedCompositeFieldContainer[_approval_pb2.PendingApproval]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., input: _Optional[str] = ..., output: _Optional[str] = ..., status: _Optional[_Union[_enum_pb2.SubAgentStatus, str]] = ..., started_at: _Optional[str] = ..., completed_at: _Optional[str] = ..., error: _Optional[str] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., tool_calls: _Optional[_Iterable[_Union[_message_pb2.ToolCall, _Mapping]]] = ..., messages: _Optional[_Iterable[_Union[_message_pb2.AgentMessage, _Mapping]]] = ..., usage: _Optional[_Union[_usage_pb2.UsageMetrics, _Mapping]] = ..., subject: _Optional[str] = ..., pending_approvals: _Optional[_Iterable[_Union[_approval_pb2.PendingApproval, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_api__pb2
from ai.stigmer.agentic.environment.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_spec__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/agentic/environment/v1/io.proto\x12!ai.stigmer.agentic.environment.v1\x1a+ai/stigmer/agentic/environment/v1/api.proto\x1a,ai/stigmer/agentic/environment/v1/spec.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"-\n\rEnvironmentId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"h\n\x1b\x45nvironmentSecretValueInput\x12.\n\x0e\x65nvironment_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\renvironmentId\x12\x19\n\x03key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03key\"\x8e\x02\n\x17ListEnvironmentsRequest\x12\x19\n\x03org\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03org\x12^\n\x06labels\x18\x02 \x03(\x0b\x32\x46.ai.stigmer.agentic.environment.v1.ListEnvironmentsRequest.LabelsEntryR\x06labels\x12=\n\tpage_info\x18\x03 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"x\n\x0f\x45nvironmentList\x12\x1f\n\x0btotal_count\x18\x01 \x01(\x05R\ntotalCount\x12\x44\n\x05items\x18\x02 \x03(\x0b\x32..ai.stigmer.agentic.environment.v1.EnvironmentR\x05items\"\xb9\x02\n!UpdateEnvironmentVariablesRequest\x12.\n\x0e\x65nvironment_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\renvironmentId\x12q\n\tvariables\x18\x02 \x03(\x0b\x32S.ai.stigmer.agentic.environment.v1.UpdateEnvironmentVariablesRequest.VariablesEntryR\tvariables\x1aq\n\x0eVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.ai.stigmer.agentic.environment.v1.EnvironmentValueR\x05value:\x02\x38\x01\"q\n!RemoveEnvironmentVariablesRequest\x12.\n\x0e\x65nvironment_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\renvironmentId\x12\x1c\n\x04keys\x18\x02 \x03(\tB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x04keysB\xd9\x01\n%com.ai.stigmer.agentic.environment.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\007IoProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTID'].fields_by_name['value']._loaded_options = None
  _globals['_ENVIRONMENTID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['environment_id']._loaded_options = None
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['environment_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['key']._loaded_options = None
  _globals['_ENVIRONMENTSECRETVALUEINPUT'].fields_by_name['key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_LISTENVIRONMENTSREQUEST'].fields_by_name['org']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._loaded_options = None
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._loaded_options = None
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['environment_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['keys']._loaded_options = None
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST'].fields_by_name['keys']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_ENVIRONMENTID']._serialized_start=242
  _globals['_ENVIRONMENTID']._serialized_end=287
  _globals['_ENVIRONMENTSECRETVALUEINPUT']._serialized_start=289
  _globals['_ENVIRONMENTSECRETVALUEINPUT']._serialized_end=393
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_start=396
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_end=666
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._serialized_start=609
  _globals['_LISTENVIRONMENTSREQUEST_LABELSENTRY']._serialized_end=666
  _globals['_ENVIRONMENTLIST']._serialized_start=668
  _globals['_ENVIRONMENTLIST']._serialized_end=788
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST']._serialized_start=791
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST']._serialized_end=1104
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._serialized_start=991
  _globals['_UPDATEENVIRONMENTVARIABLESREQUEST_VARIABLESENTRY']._serialized_end=1104
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST']._serialized_start=1106
  _globals['_REMOVEENVIRONMENTVARIABLESREQUEST']._serialized_end=1219
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityProviderSpec(_message.Message):
    __slots__ = ("display_name", "jwks_uri", "allowed_issuers", "expected_audience", "rate_limit_budget", "userinfo_endpoint")
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_ISSUERS_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    RATE_LIMIT_BUDGET_FIELD_NUMBER: _ClassVar[int]
    USERINFO_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    jwks_uri: str
    allowed_issuers: _containers.RepeatedScalarFieldContainer[str]
    expected_audience: str
    rate_limit_budget: int
    userinfo_endpoint: str
    def __init__(self, display_name: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., allowed_issuers: _Optional[_Iterable[str]] = ..., expected_audience: _Optional[str] = ..., rate_limit_budget: _Optional[int] = ..., userinfo_endpoint: _Optional[str] = ...) -> None: ...



from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from ai.stigmer.iam.identityaccount.v1 import enum_pb2 as _enum_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityAccountSpec(_message.Message):
    __slots__ = ("idp_id", "email", "first_name", "last_name", "picture_url", "is_machine_account", "provisioning_mode", "identity_provider_ref")
    IDP_ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_URL_FIELD_NUMBER: _ClassVar[int]
    IS_MACHINE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    PROVISIONING_MODE_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_REF_FIELD_NUMBER: _ClassVar[int]
    idp_id: str
    email: str
    first_name: str
    last_name: str
    picture_url: str
    is_machine_account: bool
    provisioning_mode: _enum_pb2.IdentityAccountProvisioningMode
    identity_provider_ref: _io_pb2.ApiResourceReference
    def __init__(self, idp_id: _Optional[str] = ..., email: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., picture_url: _Optional[str] = ..., is_machine_account: bool = ..., provisioning_mode: _Optional[_Union[_enum_pb2.IdentityAccountProvisioningMode, str]] = ..., identity_provider_ref: _Optional[_Union[_io_pb2.ApiResourceReference, _Mapping]] = ...) -> None: ...



import datetime

from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiKeySpec(_message.Message):
    __slots__ = ("key_hash", "fingerprint", "expires_at", "never_expires")
    KEY_HASH_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    NEVER_EXPIRES_FIELD_NUMBER: _ClassVar[int]
    key_hash: str
    fingerprint: str
    expires_at: _timestamp_pb2.Timestamp
    never_expires: bool
    def __init__(self, key_hash: _Optional[str] = ..., fingerprint: _Optional[str] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., never_expires: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_api__pb2
from ai.stigmer.agentic.environment.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/environment/v1/command.proto\x12!ai.stigmer.agentic.environment.v1\x1a+ai/stigmer/agentic/environment/v1/api.proto\x1a*ai/stigmer/agentic/environment/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xc1\x08\n\x1c\x45nvironmentCommandController\x12g\n\x05\x61pply\x12..ai.stigmer.agentic.environment.v1.Environment\x1a..ai.stigmer.agentic.environment.v1.Environment\x12\xb9\x01\n\x06\x63reate\x12..ai.stigmer.agentic.environment.v1.Environment\x1a..ai.stigmer.agentic.environment.v1.Environment\"O\xc2\xb8\x18K\x08\x1b\x10\x1e\"\x0cmetadata.org*7unauthorized to create environment in this organization\x12\xa3\x01\n\x06update\x12..ai.stigmer.agentic.environment.v1.Environment\x1a..ai.stigmer.agentic.environment.v1.Environment\"9\xc2\xb8\x18\x35\x08\x04\x10\x35\"\x0bmetadata.id*\"unauthorized to update environment\x12\xab\x01\n\x06\x64\x65lete\x12\x36.ai.stigmer.commons.apiresource.ApiResourceDeleteInput\x1a..ai.stigmer.agentic.environment.v1.Environment\"9\xc2\xb8\x18\x35\x08\x04\x10\x35\"\x0bmetadata.id*\"unauthorized to delete environment\x12\xcf\x01\n\x0fupdateVariables\x12\x44.ai.stigmer.agentic.environment.v1.UpdateEnvironmentVariablesRequest\x1a..ai.stigmer.agentic.environment.v1.Environment\"F\xc2\xb8\x18\x42\x08\x04\x10\x35\"\x0e\x65nvironment_id*,unauthorized to update environment variables\x12\xcf\x01\n\x0fremoveVariables\x12\x44.ai.stigmer.agentic.environment.v1.RemoveEnvironmentVariablesRequest\x1a..ai.stigmer.agentic.environment.v1.Environment\"F\xc2\xb8\x18\x42\x08\x04\x10\x35\"\x0e\x65nvironment_id*,unauthorized to remove environment variables\x1a\x04\xa0\xff+5B\xde\x01\n%com.ai.stigmer.agentic.environment.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\014CommandProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._serialized_options = b'\240\377+5'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\302\270\030K\010\033\020\036\"\014metadata.org*7unauthorized to create environment in this organization'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0305\010\004\0205\"\013metadata.id*\"unauthorized to update environment'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0305\010\004\0205\"\013metadata.id*\"unauthorized to delete environment'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['updateVariables']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['updateVariables']._serialized_options = b'\302\270\030B\010\004\0205\"\016environment_id*,unauthorized to update environment variables'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['removeVariables']._loaded_options = None
  _globals['_ENVIRONMENTCOMMANDCONTROLLER'].methods_by_name['removeVariables']._serialized_options = b'\302\270\030B\010\004\0205\"\016environment_id*,unauthorized to remove environment variables'
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._serialized_start=342
  _globals['_ENVIRONMENTCOMMANDCONTROLLER']._serialized_end=1431
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.environment.v1 import spec_pb2 as _spec_pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AgentSpec(_message.Message):
    __slots__ = ("description", "icon_url", "instructions", "mcp_server_usages", "skill_refs", "sub_agents", "env_spec")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ICON_URL_FIELD_NUMBER: _ClassVar[int]
    INSTRUCTIONS_FIELD_NUMBER: _ClassVar[int]
    MCP_SERVER_USAGES_FIELD_NUMBER: _ClassVar[int]
    SKILL_REFS_FIELD_NUMBER: _ClassVar[int]
    SUB_AGENTS_FIELD_NUMBER: _ClassVar[int]
    ENV_SPEC_FIELD_NUMBER: _ClassVar[int]
    description: str
    icon_url: str
    instructions: str
    mcp_server_usages: _containers.RepeatedCompositeFieldContainer[McpServerUsage]
    skill_refs: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    sub_agents: _containers.RepeatedCompositeFieldContainer[SubAgent]
    env_spec: _spec_pb2.EnvironmentSpec
    def __init__(self, description: _Optional[str] = ..., icon_url: _Optional[str] = ..., instructions: _Optional[str] = ..., mcp_server_usages: _Optional[_Iterable[_Union[McpServerUsage, _Mapping]]] = ..., skill_refs: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ..., sub_agents: _Optional[_Iterable[_Union[SubAgent, _Mapping]]] = ..., env_spec: _Optional[_Union[_spec_pb2.EnvironmentSpec, _Mapping]] = ...) -> None: ...

class SubAgent(_message.Message):
    __slots__ = ("name", "description", "instructions", "mcp_access", "skill_refs", "model_override")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    INSTRUCTIONS_FIELD_NUMBER: _ClassVar[int]
    MCP_ACCESS_FIELD_NUMBER: _ClassVar[int]
    SKILL_REFS_FIELD_NUMBER: _ClassVar[int]
    MODEL_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    instructions: str
    mcp_access: _containers.RepeatedCompositeFieldContainer[McpAccess]
    skill_refs: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    model_override: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., instructions: _Optional[str] = ..., mcp_access: _Optional[_Iterable[_Union[McpAccess, _Mapping]]] = ..., skill_refs: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ..., model_override: _Optional[str] = ...) -> None: ...

class McpServerUsage(_message.Message):
    __slots__ = ("mcp_server_ref", "enabled_tools", "tool_approval_overrides")
    MCP_SERVER_REF_FIELD_NUMBER: _ClassVar[int]
    ENABLED_TOOLS_FIELD_NUMBER: _ClassVar[int]
    TOOL_APPROVAL_OVERRIDES_FIELD_NUMBER: _ClassVar[int]
    mcp_server_ref: _io_pb2.ApiResourceReference
    enabled_tools: _containers.RepeatedScalarFieldContainer[str]
    tool_approval_overrides: _containers.RepeatedCompositeFieldContainer[ToolApprovalOverride]
    def __init__(self, mcp_server_ref: _Optional[_Union[_io_pb2.ApiResourceReference, _Mapping]] = ..., enabled_tools: _Optional[_Iterable[str]] = ..., tool_approval_overrides: _Optional[_Iterable[_Union[ToolApprovalOverride, _Mapping]]] = ...) -> None: ...

class McpAccess(_message.Message):
    __slots__ = ("mcp_server", "enabled_tools")
    MCP_SERVER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_TOOLS_FIELD_NUMBER: _ClassVar[int]
    mcp_server: str
    enabled_tools: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, mcp_server: _Optional[str] = ..., enabled_tools: _Optional[_Iterable[str]] = ...) -> None: ...

class ToolApprovalOverride(_message.Message):
    __slots__ = ("tool_name", "requires_approval", "message")
    TOOL_NAME_FIELD_NUMBER: _ClassVar[int]
    REQUIRES_APPROVAL_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    tool_name: str
    requires_approval: bool
    message: str
    def __init__(self, tool_name: _Optional[str] = ..., requires_approval: bool = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.iam.identityaccount.v1 import enum_pb2 as ai_dot_stigmer_dot_iam_dot_identityaccount_dot_v1_dot_enum__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/iam/identityaccount/v1/spec.proto\x12!ai.stigmer.iam.identityaccount.v1\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a,ai/stigmer/iam/identityaccount/v1/enum.proto\x1a\x1b\x62uf/validate/validate.proto\"\xb0\x03\n\x13IdentityAccountSpec\x12\x1d\n\x06idp_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05idpId\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x1f\n\x0bpicture_url\x18\x05 \x01(\tR\npictureUrl\x12,\n\x12is_machine_account\x18\x06 \x01(\x08R\x10isMachineAccount\x12o\n\x11provisioning_mode\x18\x07 \x01(\x0e\x32\x42.ai.stigmer.iam.identityaccount.v1.IdentityAccountProvisioningModeR\x10provisioningMode\x12h\n\x15identity_provider_ref\x18\x08 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceReferenceR\x13identityProviderRefB\xdb\x01\n%com.ai.stigmer.iam.identityaccount.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\tSpecProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_IDENTITYACCOUNTSPEC'].fields_by_name['idp_id']._loaded_options = None
  _globals['_IDENTITYACCOUNTSPEC'].fields_by_name['idp_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_IDENTITYACCOUNTSPEC']._serialized_start=200
  _globals['_IDENTITYACCOUNTSPEC']._serialized_end=632
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.mcpserver.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2
from ai.stigmer.agentic.mcpserver.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/agentic/mcpserver/v1/command.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a)ai/stigmer/agentic/mcpserver/v1/api.proto\x1a(ai/stigmer/agentic/mcpserver/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xc8\x07\n\x1aMcpServerCommandController\x12_\n\x05\x61pply\x12*.ai.stigmer.agentic.mcpserver.v1.McpServer\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\x12\x66\n\x06\x63reate\x12*.ai.stigmer.agentic.mcpserver.v1.McpServer\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"\x04\xd0\xb8\x18\x01\x12\x9a\x01\n\x06update\x12*.ai.stigmer.agentic.mcpserver.v1.McpServer\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"8\xc2\xb8\x18\x34\x08\x04\x10,\"\x0bmetadata.id*!unauthorized to update mcp server\x12\xa6\x01\n\x06\x64\x65lete\x12\x36.ai.stigmer.commons.apiresource.ApiResourceDeleteInput\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"8\xc2\xb8\x18\x34\x08\x02\x10,\"\x0bresource_id*!unauthorized to delete mcp server\x12\xba\x01\n\x10updateVisibility\x12\x35.ai.stigmer.commons.apiresource.UpdateVisibilityInput\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"C\xc2\xb8\x18?\x08\x04\x10,\"\x0bresource_id*,unauthorized to update mcp server visibility\x12\xd7\x01\n\x1cupdateDiscoveredCapabilities\x12\x42.ai.stigmer.agentic.mcpserver.v1.UpdateDiscoveredCapabilitiesInput\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"G\xc2\xb8\x18\x43\x08\x04\x10,\"\rmcp_server_id*.unauthorized to update mcp server capabilities\x1a\x04\xa0\xff+,B\xd4\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\014CommandProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_MCPSERVERCOMMANDCONTROLLER']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER']._serialized_options = b'\240\377+,'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0304\010\004\020,\"\013metadata.id*!unauthorized to update mcp server'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0304\010\002\020,\"\013resource_id*!unauthorized to delete mcp server'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateVisibility']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateVisibility']._serialized_options = b'\302\270\030?\010\004\020,\"\013resource_id*,unauthorized to update mcp server visibility'
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateDiscoveredCapabilities']._loaded_options = None
  _globals['_MCPSERVERCOMMANDCONTROLLER'].methods_by_name['updateDiscoveredCapabilities']._serialized_options = b'\302\270\030C\010\004\020,\"\rmcp_server_id*.unauthorized to update mcp server capabilities'
  _globals['_MCPSERVERCOMMANDCONTROLLER']._serialized_start=334
  _globals['_MCPSERVERCOMMANDCONTROLLER']._serialized_end=1302
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/usage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/usage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/stigmer/agentic/agentexecution/v1/usage.proto\x12$ai.stigmer.agentic.agentexecution.v1\"\xad\x06\n\x0cUsageMetrics\x12#\n\rprompt_tokens\x18\x01 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x02 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens\x12$\n\x0ellm_call_count\x18\x04 \x01(\x05R\x0cllmCallCount\x12#\n\rprimary_model\x18\x05 \x01(\tR\x0cprimaryModel\x12\x32\n\x15\x63\x61\x63he_creation_tokens\x18\x06 \x01(\x05R\x13\x63\x61\x63heCreationTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x07 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12Y\n\x0fmodel_breakdown\x18\x08 \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.ModelUsageR\x0emodelBreakdown\x12,\n\x12\x65stimated_cost_usd\x18\t \x01(\x01R\x10\x65stimatedCostUsd\x12=\n\x1btool_result_chars_truncated\x18\n \x01(\x03R\x18toolResultCharsTruncated\x12Q\n\tllm_calls\x18\x0b \x03(\x0b\x32\x34.ai.stigmer.agentic.agentexecution.v1.LlmCallMetricsR\x08llmCalls\x12*\n\x11total_duration_ms\x18\x0c \x01(\x05R\x0ftotalDurationMs\x12&\n\x0fllm_duration_ms\x18\r \x01(\x05R\rllmDurationMs\x12(\n\x10tool_duration_ms\x18\x0e \x01(\x05R\x0etoolDurationMs\x12\x39\n\x19\x61pproval_wait_duration_ms\x18\x0f \x01(\x05R\x16\x61pprovalWaitDurationMs\x12)\n\x10primary_provider\x18\x10 \x01(\tR\x0fprimaryProvider\"\xab\x04\n\nModelUsage\x12\x14\n\x05model\x18\x01 \x01(\tR\x05model\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12!\n\x0cinput_tokens\x18\x03 \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x04 \x01(\x05R\x0coutputTokens\x12\x32\n\x15\x63\x61\x63he_creation_tokens\x18\x05 \x01(\x05R\x13\x63\x61\x63heCreationTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x06 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12\x1d\n\ncall_count\x18\x07 \x01(\x05R\tcallCount\x12\x35\n\x17input_price_per_million\x18\x08 \x01(\x01R\x14inputPricePerMillion\x12\x37\n\x18output_price_per_million\x18\t \x01(\x01R\x15outputPricePerMillion\x12\x46\n cache_creation_price_per_million\x18\n \x01(\x01R\x1c\x63\x61\x63heCreationPricePerMillion\x12>\n\x1c\x63\x61\x63he_read_price_per_million\x18\x0b \x01(\x01R\x18\x63\x61\x63heReadPricePerMillion\x12,\n\x12\x65stimated_cost_usd\x18\x0c \x01(\x01R\x10\x65stimatedCostUsd\"\xf3\x02\n\x0eLlmCallMetrics\x12\x1a\n\x08sequence\x18\x01 \x01(\x05R\x08sequence\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12!\n\x0cinput_tokens\x18\x04 \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x05 \x01(\x05R\x0coutputTokens\x12\x32\n\x15\x63\x61\x63he_creation_tokens\x18\x06 \x01(\x05R\x13\x63\x61\x63heCreationTokens\x12*\n\x11\x63\x61\x63he_read_tokens\x18\x07 \x01(\x05R\x0f\x63\x61\x63heReadTokens\x12,\n\x12\x65stimated_cost_usd\x18\x08 \x01(\x01R\x10\x65stimatedCostUsd\x12\x1f\n\x0b\x64uration_ms\x18\t \x01(\x05R\ndurationMs\x12\x1c\n\ttimestamp\x18\n \x01(\tR\ttimestampB\xeb\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\nUsageProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.usage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\nUsageProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_USAGEMETRICS']._serialized_start=91
  _globals['_USAGEMETRICS']._serialized_end=904
  _globals['_MODELUSAGE']._serialized_start=907
  _globals['_MODELUSAGE']._serialized_end=1462
  _globals['_LLMCALLMETRICS']._serialized_start=1465
  _globals['_LLMCALLMETRICS']._serialized_end=1836
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGai/stigmer/commons/apiresource/apiresourcekind/api_resource_group.proto\x12.ai.stigmer.commons.apiresource.apiresourcekind\x1a google/protobuf/descriptor.proto\"Q\n\x14\x41piResourceGroupMeta\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName*\xba\x01\n\x10\x41piResourceGroup\x12\"\n\x1e\x61pi_resource_group_unspecified\x10\x00\x12.\n\x07\x61gentic\x10\x01\x1a!\xea\xbd,\x1d\n\x12\x61gentic.stigmer.ai\x12\x07\x41gentic\x12\"\n\x03iam\x10\x02\x1a\x19\xea\xbd,\x15\n\x0eiam.stigmer.ai\x12\x03IAM\x12.\n\x07tenancy\x10\x03\x1a!\xea\xbd,\x1d\n\x12tenancy.stigmer.ai\x12\x07Tenancy:\x88\x01\n\ngroup_meta\x12!.google.protobuf.EnumValueOptions\x18\xdd\xc7\x05 \x01(\x0b\x32\x44.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceGroupMetaR\tgroupMetaB\xa9\x02\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\x15\x41piResourceGroupProtoP\x01\xa2\x02\x05\x41SCAA\xaa\x02.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\xca\x02.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\xe2\x02:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\xea\x02\x32\x41i::Stigmer::Commons::Apiresource::Apiresourcekindb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.apiresourcekind.api_resource_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n2com.ai.stigmer.commons.apiresource.apiresourcekindB\025ApiResourceGroupProtoP\001\242\002\005ASCAA\252\002.Ai.Stigmer.Commons.Apiresource.Apiresourcekind\312\002.Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\342\002:Ai\\Stigmer\\Commons\\Apiresource\\Apiresourcekind\\GPBMetadata\352\0022Ai::Stigmer::Commons::Apiresource::Apiresourcekind'
  _globals['_APIRESOURCEGROUP'].values_by_name["agentic"]._loaded_options = None
  _globals['_APIRESOURCEGROUP'].values_by_name["agentic"]._serialized_options = b'\352\275,\035\n\022agentic.stigmer.ai\022\007Agentic'
  _globals['_APIRESOURCEGROUP'].values_by_name["iam"]._loaded_options = None
  _globals['_APIRESOURCEGROUP'].values_by_name["iam"]._serialized_options = b'\352\275,\025\n\016iam.stigmer.ai\022\003IAM'
  _globals['_APIRESOURCEGROUP'].values_by_name["tenancy"]._loaded_options = None
  _globals['_APIRESOURCEGROUP'].values_by_name["tenancy"]._serialized_options = b'\352\275,\035\n\022tenancy.stigmer.ai\022\007Tenancy'
  _globals['_APIRESOURCEGROUP']._serialized_start=241
  _globals['_APIRESOURCEGROUP']._serialized_end=427
  _globals['_APIRESOURCEGROUPMETA']._serialized_start=157
  _globals['_APIRESOURCEGROUPMETA']._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/listen.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/listen.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ai/stigmer/agentic/workflow/v1/tasks/listen.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\"f\n\x10ListenTaskConfig\x12\x46\n\x02to\x18\x01 \x01(\x0b\x32..ai.stigmer.agentic.workflow.v1.tasks.ListenToB\x06\xbaH\x03\xc8\x01\x01R\x02to:\n\xea\x8b,\x06listen\"\x88\x01\n\x08ListenTo\x12&\n\x04mode\x18\x01 \x01(\tB\x12\xbaH\x0fr\nR\x03oneR\x03\x61ll\xc8\x01\x01R\x04mode\x12T\n\x07signals\x18\x02 \x03(\x0b\x32\x30.ai.stigmer.agentic.workflow.v1.tasks.SignalSpecB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x07signals\"]\n\nSignalSpec\x12\x1a\n\x02id\x18\x01 \x01(\tB\n\xbaH\x07r\x02\x10\x01\xc8\x01\x01R\x02id\x12\x33\n\x04type\x18\x02 \x01(\tB\x1f\xbaH\x1cr\x17R\x06signalR\x05queryR\x06update\xc8\x01\x01R\x04typeB\xef\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\x0bListenProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.listen_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\013ListenProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_LISTENTASKCONFIG'].fields_by_name['to']._loaded_options = None
  _globals['_LISTENTASKCONFIG'].fields_by_name['to']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTENTASKCONFIG']._loaded_options = None
  _globals['_LISTENTASKCONFIG']._serialized_options = b'\352\213,\006listen'
  _globals['_LISTENTO'].fields_by_name['mode']._loaded_options = None
  _globals['_LISTENTO'].fields_by_name['mode']._serialized_options = b'\272H\017r\nR\003oneR\003all\310\001\001'
  _globals['_LISTENTO'].fields_by_name['signals']._loaded_options = None
  _globals['_LISTENTO'].fields_by_name['signals']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_SIGNALSPEC'].fields_by_name['id']._loaded_options = None
  _globals['_SIGNALSPEC'].fields_by_name['id']._serialized_options = b'\272H\007r\002\020\001\310\001\001'
  _globals['_SIGNALSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_SIGNALSPEC'].fields_by_name['type']._serialized_options = b'\272H\034r\027R\006signalR\005queryR\006update\310\001\001'
  _globals['_LISTENTASKCONFIG']._serialized_start=172
  _globals['_LISTENTASKCONFIG']._serialized_end=274
  _globals['_LISTENTO']._serialized_start=277
  _globals['_LISTENTO']._serialized_end=413
  _globals['_SIGNALSPEC']._serialized_start=415
  _globals['_SIGNALSPEC']._serialized_end=508
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Auth0Webhook(_message.Message):
    __slots__ = ("date", "type", "description", "client_id", "client_name", "ip", "user_agent", "user_id")
    DATE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    date: str
    type: str
    description: str
    client_id: str
    client_name: str
    ip: str
    user_agent: str
    user_id: str
    def __init__(self, date: _Optional[str] = ..., type: _Optional[str] = ..., description: _Optional[str] = ..., client_id: _Optional[str] = ..., client_name: _Optional[str] = ..., ip: _Optional[str] = ..., user_agent: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowexecution/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowexecution/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.executioncontext.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_executioncontext_dot_v1_dot_spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/workflowexecution/v1/spec.proto\x12\'ai.stigmer.agentic.workflowexecution.v1\x1a\x31\x61i/stigmer/agentic/executioncontext/v1/spec.proto\"\xe6\x04\n\x15WorkflowExecutionSpec\x12\x30\n\x14workflow_instance_id\x18\x01 \x01(\tR\x12workflowInstanceId\x12\x1f\n\x0bworkflow_id\x18\x06 \x01(\tR\nworkflowId\x12\'\n\x0ftrigger_message\x18\x03 \x01(\tR\x0etriggerMessage\x12~\n\x10trigger_metadata\x18\x04 \x03(\x0b\x32S.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionSpec.TriggerMetadataEntryR\x0ftriggerMetadata\x12o\n\x0bruntime_env\x18\x05 \x03(\x0b\x32N.ai.stigmer.agentic.workflowexecution.v1.WorkflowExecutionSpec.RuntimeEnvEntryR\nruntimeEnv\x12%\n\x0e\x63\x61llback_token\x18\x07 \x01(\x0cR\rcallbackToken\x1a\x42\n\x14TriggerMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1au\n\x0fRuntimeEnvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12L\n\x05value\x18\x02 \x01(\x0b\x32\x36.ai.stigmer.agentic.executioncontext.v1.ExecutionValueR\x05value:\x02\x38\x01\x42\xf9\x01\n+com.ai.stigmer.agentic.workflowexecution.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\'Ai.Stigmer.Agentic.Workflowexecution.V1\xca\x02\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\xe2\x02\x33\x41i\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\xea\x02+Ai::Stigmer::Agentic::Workflowexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowexecution.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ai.stigmer.agentic.workflowexecution.v1B\tSpecProtoP\001\242\002\004ASAW\252\002\'Ai.Stigmer.Agentic.Workflowexecution.V1\312\002\'Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\342\0023Ai\\Stigmer\\Agentic\\Workflowexecution\\V1\\GPBMetadata\352\002+Ai::Stigmer::Agentic::Workflowexecution::V1'
  _globals['_WORKFLOWEXECUTIONSPEC_TRIGGERMETADATAENTRY']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONSPEC_TRIGGERMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_WORKFLOWEXECUTIONSPEC_RUNTIMEENVENTRY']._loaded_options = None
  _globals['_WORKFLOWEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_options = b'8\001'
  _globals['_WORKFLOWEXECUTIONSPEC']._serialized_start=147
  _globals['_WORKFLOWEXECUTIONSPEC']._serialized_end=761
  _globals['_WORKFLOWEXECUTIONSPEC_TRIGGERMETADATAENTRY']._serialized_start=576
  _globals['_WORKFLOWEXECUTIONSPEC_TRIGGERMETADATAENTRY']._serialized_end=642
  _globals['_WORKFLOWEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_start=644
  _globals['_WORKFLOWEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_end=761
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class AgentExecutionCommandControllerStub(object):
    """AgentExecutionCommandController handles write operations for agent executions.
    Follows the standard pattern: create, update, delete (no granular field updates).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/create',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/update',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.updateStatus = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/updateStatus',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionUpdateStatusInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.submitApproval = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/submitApproval',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.SubmitApprovalInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.cancel = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/cancel',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.CancelAgentExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.terminate = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/terminate',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.TerminateAgentExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.recover = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/recover',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.RecoverAgentExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.pause = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/pause',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.PauseAgentExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.resume = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/resume',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ResumeAgentExecutionInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.uploadAttachment = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/uploadAttachment',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.UploadAttachmentRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.UploadAttachmentResponse.FromString,
                _registered_method=True)


class AgentExecutionCommandControllerServicer(object):
    """AgentExecutionCommandController handles write operations for agent executions.
    Follows the standard pattern: create, update, delete (no granular field updates).
    """

    def create(self, request, context):
        """Create and trigger a new agent execution.
        Session is optional - can be provided or auto-created from agent_id.
        Authorization is handled in handler:
        - If session_id provided: checks can_create_execution_in on session
        - If session_id NOT provided: checks can_create_execution_in on organization
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update an execution with full state.
        Used by users to update execution configuration (spec fields).
        No individual field updates - always provide complete state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateStatus(self, request, context):
        """Update execution status during agent execution.
        Used by agent-runner to send progressive status updates (messages, tool_calls, phase, etc.)
        This RPC is optimized for frequent status updates and merges status fields with existing state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete an execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def submitApproval(self, request, context):
        """Submit approval decision for a pending tool call (HITL Phase 1).

        ## Preconditions

        - Execution must be in EXECUTION_WAITING_FOR_APPROVAL phase
        - tool_call_id must match status.pending_approval.tool_call_id
        - User must have can_edit permission on the execution

        ## Behavior by Action

        - APPROVE: Tool executes normally, execution resumes to IN_PROGRESS
        - SKIP: Tool returns skip message to LLM, execution continues to IN_PROGRESS
        - REJECT: Execution fails with rejection error, phase becomes FAILED

        ## State Transitions

        On success:
        - ToolCall.approval_action = submitted action
        - ToolCall.approval_decided_at = current timestamp
        - ToolCall.approved_by = authenticated user ID
        - AgentExecutionStatus.pending_approval = cleared
        - ExecutionPhase = EXECUTION_IN_PROGRESS (or EXECUTION_FAILED if REJECT)

        ## Error Conditions

        - NOT_FOUND: Execution doesn't exist
        - FAILED_PRECONDITION: Execution not in WAITING_FOR_APPROVAL phase
        - INVALID_ARGUMENT: tool_call_id doesn't match pending approval, or action is UNSPECIFIED
        - PERMISSION_DENIED: User lacks can_edit permission

        ## Idempotency

        If the same approval is submitted twice (same execution, tool_call, action),
        the second call is a no-op and returns the current state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cancel(self, request, context):
        """─────────────────────────────────────────────────────────────────────────────
        Lifecycle Control Operations

        These RPCs control the agent execution lifecycle, mapping to Temporal
        workflow operations. They enable users to gracefully stop, force-stop,
        pause, resume, or recover agent executions.
        ─────────────────────────────────────────────────────────────────────────────

        Cancel a running agent execution gracefully.

        Sends a cancellation signal to the agent execution via Temporal's CancelWorkflow API.
        The agent can handle the cancellation signal to save checkpoint and clean up
        before transitioning to the CANCELLED phase.

        Temporal Equivalent: `temporal workflow cancel --workflow-id <id>`

        ## Behavior

        1. Validates execution exists and is in a cancellable phase
        2. Sends cancellation signal to Temporal workflow
        3. Python activity receives cancellation and saves LangGraph checkpoint
        4. Execution transitions to EXECUTION_CANCELLED phase
        5. Returns updated AgentExecution with new phase

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot cancel already-terminal executions (COMPLETED, FAILED, CANCELLED, TERMINATED)

        ## State Transitions

        - status.phase: PENDING/IN_PROGRESS → CANCELLED
        - status.completed_at: Set to current timestamp
        - LangGraph checkpoint: Preserved for potential future reference

        ## Idempotency

        Cancelling an already-cancelled execution succeeds as a no-op.
        The call returns the current execution state without side effects.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION: Execution is in a terminal phase
        - INVALID_ARGUMENT: ID is empty or malformed

        @since Agent Execution Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def terminate(self, request, context):
        """Terminate an agent execution immediately.

        Force-stops the agent execution via Temporal's TerminateWorkflow API without
        allowing cleanup. Unlike cancel, the agent cannot respond to termination -
        it is stopped immediately. Use this for stuck or unresponsive agents.

        Temporal Equivalent: `temporal workflow terminate --workflow-id <id>`

        ## Behavior

        1. Validates execution exists and is in a terminable phase
        2. Force-kills workflow via Temporal (no signal sent to agent)
        3. Execution transitions to EXECUTION_TERMINATED phase immediately
        4. No cleanup callbacks or checkpoint saves occur
        5. Returns updated AgentExecution with TERMINATED phase

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot terminate already-terminal executions

        ## State Transitions

        - status.phase: PENDING/IN_PROGRESS → TERMINATED
        - status.completed_at: Set to current timestamp
        - LangGraph checkpoint: May be incomplete (no graceful save)

        ## Terminated vs Cancelled

        | Aspect | cancel | terminate |
        |--------|--------|-----------|
        | Signal to agent | Yes (can handle) | No |
        | Checkpoint saved | Yes (graceful) | No |
        | Use case | Normal stop | Stuck agents |
        | Can recover? | No | No |

        ## Idempotency

        Terminating an already-terminated execution succeeds as a no-op.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission on the execution
        - FAILED_PRECONDITION: Execution is in a terminal phase
        - INVALID_ARGUMENT: ID is empty or malformed

        @since Agent Execution Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def recover(self, request, context):
        """Recover a failed agent execution from the last checkpoint.

        Resumes execution from the last LangGraph checkpoint using Temporal's
        ResetWorkflow API. Completed work is preserved - successful tool calls
        are NOT re-executed.

        Temporal Equivalent: `temporal workflow reset --workflow-id <id> --type LastWorkflowTask`

        ## Behavior

        1. Validates execution is in FAILED phase (recoverable)
        2. Uses Temporal ResetWorkflow to resume from last checkpoint
        3. Activity re-invoked with same thread_id
        4. LangGraph loads from checkpoint automatically
        5. Execution transitions from FAILED to IN_PROGRESS phase
        6. Agent continues from where it failed

        ## Preconditions

        - Execution must be in EXECUTION_FAILED phase
        - TERMINATED executions cannot be recovered (incomplete checkpoint)
        - CANCELLED executions cannot be recovered (intentional user action)

        ## State Transitions

        - status.phase: FAILED → IN_PROGRESS
        - status.completed_at: Cleared
        - status.error: Cleared
        - Completed tool calls: Preserved (not re-executed)

        ## Idempotency

        If recovery already succeeded (execution is now IN_PROGRESS),
        the call succeeds as a no-op.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission
        - FAILED_PRECONDITION: Execution is not in FAILED phase
        - INVALID_ARGUMENT: ID is empty or malformed

        @since Agent Execution Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def pause(self, request, context):
        """Pause a running agent execution.

        Temporarily stops the agent at its current checkpoint. Unlike cancel,
        the execution is NOT terminal and can be resumed later from where it left off.

        ## Behavior

        1. Validates execution exists and is in a pausable phase
        2. Sends "pause" signal to Temporal workflow
        3. Workflow cancels running activity gracefully
        4. Python activity saves LangGraph checkpoint on cancellation
        5. Execution transitions to EXECUTION_PAUSED phase
        6. Workflow waits for resume signal (no resources consumed)

        ## Preconditions

        - Execution must be in EXECUTION_PENDING or EXECUTION_IN_PROGRESS phase
        - Cannot pause already-terminal or already-paused executions

        ## State Transitions

        - status.phase: PENDING/IN_PROGRESS → PAUSED
        - status.completed_at: NOT set (execution is not finished)
        - LangGraph checkpoint: Saved via thread_id

        ## Paused vs Cancelled

        | Aspect | pause | cancel |
        |--------|-------|--------|
        | Terminal state? | No | Yes |
        | Can resume? | Yes (via resume RPC) | No |
        | Checkpoint saved? | Yes | Best-effort |
        | Use case | Temporary stop | Permanent stop |

        ## Idempotency

        Pausing an already-paused execution succeeds as a no-op.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission
        - FAILED_PRECONDITION: Execution is in a terminal phase
        - INVALID_ARGUMENT: ID is empty or malformed

        @since Agent Execution Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def resume(self, request, context):
        """Resume a paused agent execution.

        Continues execution from the checkpoint where it was paused. The agent
        re-invokes with the same thread_id, loading from LangGraph checkpoint
        and continuing from where it left off.

        ## Behavior

        1. Validates execution is in EXECUTION_PAUSED phase
        2. Sends "resume" signal to Temporal workflow
        3. Workflow unblocks and re-invokes activity
        4. Activity loads from LangGraph checkpoint using thread_id
        5. Execution transitions back to EXECUTION_IN_PROGRESS phase
        6. Agent continues from exact pause point

        ## Preconditions

        - Execution must be in EXECUTION_PAUSED phase
        - Cannot resume non-paused executions

        ## State Transitions

        - status.phase: PAUSED → IN_PROGRESS
        - Activities: Re-invoked, load from checkpoint
        - LangGraph state: Loaded from checkpoint via thread_id

        ## Idempotency

        Resuming an already-running execution succeeds as a no-op.

        ## Error Cases

        - NOT_FOUND: Execution with given ID doesn't exist
        - PERMISSION_DENIED: User lacks can_edit permission
        - FAILED_PRECONDITION: Execution is not in PAUSED phase
        - INVALID_ARGUMENT: ID is empty or malformed

        @since Agent Execution Lifecycle
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def uploadAttachment(self, request, context):
        """─────────────────────────────────────────────────────────────────────────────
        Artifact Lifecycle Operations

        These RPCs support file attachments and artifacts for agent executions.
        Attachments are input files provided before execution; artifacts are
        output files created during execution.
        ─────────────────────────────────────────────────────────────────────────────

        Upload a file attachment for use in an agent execution.

        Pre-uploads files to artifact storage before creating an execution.
        The returned storage_key can be used in Attachment.storage_key when
        creating the execution.

        ## Authorization

        This endpoint does not require authorization. The storage_key returned
        acts as a capability token - knowing the key grants access to the content.
        This simplifies the upload flow for CLI and other clients.

        ## Storage Path

        Files are stored at: attachments/{ulid}/{filename}
        The ULID ensures unique paths and enables future cleanup policies.

        ## Use Cases

        - CLI uploading files (>4MB) before agent execution
        - Pre-uploading datasets for agent processing
        - Uploading binary files that cannot be embedded inline in Attachment

        ## Example Flow

        1. Client calls uploadAttachment with file content
        2. Server uploads to storage, returns storage_key
        3. Client creates AgentExecution with Attachment using storage_key
        4. Agent-runner downloads attachment content when execution starts

        @since Artifact Lifecycle (Attachments & Artifacts)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentExecutionCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'updateStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.updateStatus,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionUpdateStatusInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'submitApproval': grpc.unary_unary_rpc_method_handler(
                    servicer.submitApproval,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.SubmitApprovalInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.cancel,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.CancelAgentExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'terminate': grpc.unary_unary_rpc_method_handler(
                    servicer.terminate,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.TerminateAgentExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'recover': grpc.unary_unary_rpc_method_handler(
                    servicer.recover,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.RecoverAgentExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'pause': grpc.unary_unary_rpc_method_handler(
                    servicer.pause,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.PauseAgentExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'resume': grpc.unary_unary_rpc_method_handler(
                    servicer.resume,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ResumeAgentExecutionInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'uploadAttachment': grpc.unary_unary_rpc_method_handler(
                    servicer.uploadAttachment,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.UploadAttachmentRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.UploadAttachmentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AgentExecutionCommandController(object):
    """AgentExecutionCommandController handles write operations for agent executions.
    Follows the standard pattern: create, update, delete (no granular field updates).
    """

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/create',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/update',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/updateStatus',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionUpdateStatusInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/delete',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def submitApproval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/submitApproval',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.SubmitApprovalInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/cancel',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.CancelAgentExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def terminate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/terminate',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.TerminateAgentExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def recover(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/recover',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.RecoverAgentExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def pause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/pause',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.PauseAgentExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def resume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/resume',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ResumeAgentExecutionInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def uploadAttachment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionCommandController/uploadAttachment',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.UploadAttachmentRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.UploadAttachmentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as _api_resource_kind_pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import iam_permission_pb2 as _iam_permission_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RpcAuthorizationConfig(_message.Message):
    __slots__ = ("permission", "resource_kind", "resource_kind_path", "field_path", "error_msg", "resource_id")
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_KIND_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_KIND_PATH_FIELD_NUMBER: _ClassVar[int]
    FIELD_PATH_FIELD_NUMBER: _ClassVar[int]
    ERROR_MSG_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    permission: _iam_permission_pb2.ApiResourceIamPermission
    resource_kind: _api_resource_kind_pb2.ApiResourceKind
    resource_kind_path: str
    field_path: str
    error_msg: str
    resource_id: str
    def __init__(self, permission: _Optional[_Union[_iam_permission_pb2.ApiResourceIamPermission, str]] = ..., resource_kind: _Optional[_Union[_api_resource_kind_pb2.ApiResourceKind, str]] = ..., resource_kind_path: _Optional[str] = ..., field_path: _Optional[str] = ..., error_msg: _Optional[str] = ..., resource_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.iam.iampolicy.v1.rpcauthorization import io_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_io__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAai/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x12,ai.stigmer.iam.iampolicy.v1.rpcauthorization\x1a\x35\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/io.proto\x1a google/protobuf/descriptor.proto:~\n\x06\x63onfig\x12\x1e.google.protobuf.MethodOptions\x18\x88\x87\x03 \x01(\x0b\x32\x44.ai.stigmer.iam.iampolicy.v1.rpcauthorization.RpcAuthorizationConfigR\x06\x63onfig:=\n\tis_public\x12\x1e.google.protobuf.MethodOptions\x18\x89\x87\x03 \x01(\x08R\x08isPublic:T\n\x15is_skip_authorization\x12\x1e.google.protobuf.MethodOptions\x18\x8a\x87\x03 \x01(\x08R\x13isSkipAuthorizationB\x9e\x02\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\x12MethodOptionsProtoP\x01\xa2\x02\x06\x41SIIVR\xaa\x02,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\xca\x02,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\xe2\x02\x38\x41i\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\xea\x02\x31\x41i::Stigmer::Iam::Iampolicy::V1::Rpcauthorizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.rpcauthorization.method_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.ai.stigmer.iam.iampolicy.v1.rpcauthorizationB\022MethodOptionsProtoP\001\242\002\006ASIIVR\252\002,Ai.Stigmer.Iam.Iampolicy.V1.Rpcauthorization\312\002,Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\342\0028Ai\\Stigmer\\Iam\\Iampolicy\\V1\\Rpcauthorization\\GPBMetadata\352\0021Ai::Stigmer::Iam::Iampolicy::V1::Rpcauthorization'
# @@protoc_insertion_point(module_scope)
